==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkTransformToGrid.java <==
// java wrapper for vtkTransformToGrid object
//

package vtk;
import vtk.*;

public class vtkTransformToGrid extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInput_2(vtkAbstractTransform id0);
  public void SetInput(vtkAbstractTransform id0)
    { SetInput_2(id0); }

  private native long GetInput_3();
  public vtkAbstractTransform GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetGridExtent_4(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetGridExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetGridExtent_4(id0,id1,id2,id3,id4,id5); }

  private native void SetGridExtent_5(int id0[]);
  public void SetGridExtent(int id0[])
    { SetGridExtent_5(id0); }

  private native int[]  GetGridExtent_6();
  public int[]  GetGridExtent()
    { return GetGridExtent_6(); }

  private native void SetGridOrigin_7(double id0,double id1,double id2);
  public void SetGridOrigin(double id0,double id1,double id2)
    { SetGridOrigin_7(id0,id1,id2); }

  private native void SetGridOrigin_8(double id0[]);
  public void SetGridOrigin(double id0[])
    { SetGridOrigin_8(id0); }

  private native double[] GetGridOrigin_9();
  public double[] GetGridOrigin()
    { return GetGridOrigin_9(); }

  private native void SetGridSpacing_10(double id0,double id1,double id2);
  public void SetGridSpacing(double id0,double id1,double id2)
    { SetGridSpacing_10(id0,id1,id2); }

  private native void SetGridSpacing_11(double id0[]);
  public void SetGridSpacing(double id0[])
    { SetGridSpacing_11(id0); }

  private native double[] GetGridSpacing_12();
  public double[] GetGridSpacing()
    { return GetGridSpacing_12(); }

  private native void SetGridScalarType_13(int id0);
  public void SetGridScalarType(int id0)
    { SetGridScalarType_13(id0); }

  private native int GetGridScalarType_14();
  public int GetGridScalarType()
    { return GetGridScalarType_14(); }

  private native void SetGridScalarTypeToDouble_15();
  public void SetGridScalarTypeToDouble()
    { SetGridScalarTypeToDouble_15(); }

  private native void SetGridScalarTypeToFloat_16();
  public void SetGridScalarTypeToFloat()
    { SetGridScalarTypeToFloat_16(); }

  private native void SetGridScalarTypeToShort_17();
  public void SetGridScalarTypeToShort()
    { SetGridScalarTypeToShort_17(); }

  private native void SetGridScalarTypeToUnsignedShort_18();
  public void SetGridScalarTypeToUnsignedShort()
    { SetGridScalarTypeToUnsignedShort_18(); }

  private native void SetGridScalarTypeToUnsignedChar_19();
  public void SetGridScalarTypeToUnsignedChar()
    { SetGridScalarTypeToUnsignedChar_19(); }

  private native void SetGridScalarTypeToChar_20();
  public void SetGridScalarTypeToChar()
    { SetGridScalarTypeToChar_20(); }

  private native double GetDisplacementScale_21();
  public double GetDisplacementScale()
    { return GetDisplacementScale_21(); }

  private native double GetDisplacementShift_22();
  public double GetDisplacementShift()
    { return GetDisplacementShift_22(); }

  private native long GetOutput_23();
  public vtkImageData GetOutput() {
    long temp = GetOutput_23();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkTransformToGrid() { super(); }

  public vtkTransformToGrid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv6h.pkg.tar.xz: vtk/vtkTransformToGrid.java <==
// java wrapper for vtkTransformToGrid object
//

package vtk;
import vtk.*;

public class vtkTransformToGrid extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInput_2(vtkAbstractTransform id0);
  public void SetInput(vtkAbstractTransform id0)
    { SetInput_2(id0); }

  private native long GetInput_3();
  public vtkAbstractTransform GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGridExtent_4(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetGridExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetGridExtent_4(id0,id1,id2,id3,id4,id5); }

  private native void SetGridExtent_5(int id0[]);
  public void SetGridExtent(int id0[])
    { SetGridExtent_5(id0); }

  private native int[]  GetGridExtent_6();
  public int[]  GetGridExtent()
    { return GetGridExtent_6(); }

  private native void SetGridOrigin_7(double id0,double id1,double id2);
  public void SetGridOrigin(double id0,double id1,double id2)
    { SetGridOrigin_7(id0,id1,id2); }

  private native void SetGridOrigin_8(double id0[]);
  public void SetGridOrigin(double id0[])
    { SetGridOrigin_8(id0); }

  private native double[] GetGridOrigin_9();
  public double[] GetGridOrigin()
    { return GetGridOrigin_9(); }

  private native void SetGridSpacing_10(double id0,double id1,double id2);
  public void SetGridSpacing(double id0,double id1,double id2)
    { SetGridSpacing_10(id0,id1,id2); }

  private native void SetGridSpacing_11(double id0[]);
  public void SetGridSpacing(double id0[])
    { SetGridSpacing_11(id0); }

  private native double[] GetGridSpacing_12();
  public double[] GetGridSpacing()
    { return GetGridSpacing_12(); }

  private native void SetGridScalarType_13(int id0);
  public void SetGridScalarType(int id0)
    { SetGridScalarType_13(id0); }

  private native int GetGridScalarType_14();
  public int GetGridScalarType()
    { return GetGridScalarType_14(); }

  private native void SetGridScalarTypeToDouble_15();
  public void SetGridScalarTypeToDouble()
    { SetGridScalarTypeToDouble_15(); }

  private native void SetGridScalarTypeToFloat_16();
  public void SetGridScalarTypeToFloat()
    { SetGridScalarTypeToFloat_16(); }

  private native void SetGridScalarTypeToShort_17();
  public void SetGridScalarTypeToShort()
    { SetGridScalarTypeToShort_17(); }

  private native void SetGridScalarTypeToUnsignedShort_18();
  public void SetGridScalarTypeToUnsignedShort()
    { SetGridScalarTypeToUnsignedShort_18(); }

  private native void SetGridScalarTypeToUnsignedChar_19();
  public void SetGridScalarTypeToUnsignedChar()
    { SetGridScalarTypeToUnsignedChar_19(); }

  private native void SetGridScalarTypeToChar_20();
  public void SetGridScalarTypeToChar()
    { SetGridScalarTypeToChar_20(); }

  private native double GetDisplacementScale_21();
  public double GetDisplacementScale()
    { return GetDisplacementScale_21(); }

  private native double GetDisplacementShift_22();
  public double GetDisplacementShift()
    { return GetDisplacementShift_22(); }

  private native long GetOutput_23();
  public vtkImageData GetOutput() {
    long temp = GetOutput_23();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkTransformToGrid() { super(); }

  public vtkTransformToGrid(long id) { super(id); }
  public native long   VTKInit();

}
